package Exception::DB::DuplicateEntry;
$Exception::DB::DuplicateEntry::VERSION = '0.015';
use base qw(Exception::DB);

1;
